Class: Google::Apis::PaymentsresellersubscriptionV1::CancelSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::CancelSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Response that contains the cancelled subscription resource.
Instance Attribute Summary collapse
-
#subscription ⇒ Google::Apis::PaymentsresellersubscriptionV1::Subscription
Acts as a central billing entity between an external partner and Google.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelSubscriptionResponse
constructor
A new instance of CancelSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelSubscriptionResponse
Returns a new instance of CancelSubscriptionResponse.
96 97 98 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 96 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subscription ⇒ Google::Apis::PaymentsresellersubscriptionV1::Subscription
Acts as a central billing entity between an external partner and Google.
Google services use the subscription state to grant or revoke the user's
service entitlement. Note: The subscription state might not perfectly align
with the user's service entitlement. Some services might continue providing
access until the current cycle ends, even if the subscription is immediately
canceled. Consult the relevant contract or product policy for specific details.
Corresponds to the JSON property subscription
94 95 96 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 94 def subscription @subscription end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
101 102 103 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 101 def update!(**args) @subscription = args[:subscription] if args.key?(:subscription) end |