Class: Google::Apis::PaymentsresellersubscriptionV1::Duration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Describes the length of a period of a time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Duration

Returns a new instance of Duration.



184
185
186
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

number of duration units to be included. Corresponds to the JSON property count

Returns:

  • (Fixnum)


177
178
179
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 177

def count
  @count
end

#unitString

The unit used for the duration Corresponds to the JSON property unit

Returns:

  • (String)


182
183
184
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 182

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



189
190
191
192
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 189

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @unit = args[:unit] if args.key?(:unit)
end