Class: Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionIntent
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionIntent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Intent for entitling the previously provisioned subscription to an end user.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntitleSubscriptionIntent
constructor
A new instance of EntitleSubscriptionIntent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntitleSubscriptionIntent
Returns a new instance of EntitleSubscriptionIntent.
207 208 209 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. The name of the subscription resource that is entitled to the
current end user. It is in the format of "partners/partner_id/subscriptions/
subscriptionId".
Corresponds to the JSON property name
205 206 207 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 205 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
212 213 214 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 212 def update!(**args) @name = args[:name] if args.key?(:name) end |