Class: Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionRequestLineItemEntitlementDetails
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionRequestLineItemEntitlementDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
The details of the line item to be entitled.
Instance Attribute Summary collapse
-
#line_item_index ⇒ Fixnum
Required.
-
#products ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntitleSubscriptionRequestLineItemEntitlementDetails
constructor
A new instance of EntitleSubscriptionRequestLineItemEntitlementDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntitleSubscriptionRequestLineItemEntitlementDetails
Returns a new instance of EntitleSubscriptionRequestLineItemEntitlementDetails.
254 255 256 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#line_item_index ⇒ Fixnum
Required. The index of the line item to be entitled.
Corresponds to the JSON property lineItemIndex
244 245 246 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 244 def line_item_index @line_item_index end |
#products ⇒ Array<String>
Optional. Only applicable if the line item corresponds to a hard bundle.
Product resource names that identify the bundle elements to be entitled in the
line item. If unspecified, all bundle elements will be entitled. The format is
'partners/partner_id/products/product_id'.
Corresponds to the JSON property products
252 253 254 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 252 def products @products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
259 260 261 262 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 259 def update!(**args) @line_item_index = args[:line_item_index] if args.key?(:line_item_index) @products = args[:products] if args.key?(:products) end |