Class: Google::Apis::PaymentsresellersubscriptionV1::ExtendSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::ExtendSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Request message for extending a Subscription resource. A new recurrence will be made based on the subscription schedule defined by the original product.
Instance Attribute Summary collapse
-
#extension ⇒ Google::Apis::PaymentsresellersubscriptionV1::Extension
Describes the details of an extension request.
-
#request_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtendSubscriptionRequest
constructor
A new instance of ExtendSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtendSubscriptionRequest
Returns a new instance of ExtendSubscriptionRequest.
316 317 318 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extension ⇒ Google::Apis::PaymentsresellersubscriptionV1::Extension
Describes the details of an extension request.
Corresponds to the JSON property extension
306 307 308 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 306 def extension @extension end |
#request_id ⇒ String
Required. Restricted to 36 ASCII characters. A random UUID is recommended. The
idempotency key for the request. The ID generation logic is controlled by the
partner. request_id should be the same as on retries of the same request. A
different request_id must be used for a extension of a different cycle.
Corresponds to the JSON property requestId
314 315 316 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 314 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
321 322 323 324 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 321 def update!(**args) @extension = args[:extension] if args.key?(:extension) @request_id = args[:request_id] if args.key?(:request_id) end |