Class: Google::Apis::PaymentsresellersubscriptionV1::ExtendSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::ExtendSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Response that contains the timestamps after the extension.
Instance Attribute Summary collapse
-
#cycle_end_time ⇒ String
The time at which the subscription is expected to be extended, in ISO 8061 format.
-
#free_trial_end_time ⇒ String
End of the free trial period, in ISO 8061 format.
-
#renewal_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtendSubscriptionResponse
constructor
A new instance of ExtendSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtendSubscriptionResponse
Returns a new instance of ExtendSubscriptionResponse.
345 346 347 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cycle_end_time ⇒ String
The time at which the subscription is expected to be extended, in ISO 8061
format. UTC timezone. Example, "cycleEndTime":"2019-08-31T17:28:54.564Z"
Corresponds to the JSON property cycleEndTime
326 327 328 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 326 def cycle_end_time @cycle_end_time end |
#free_trial_end_time ⇒ String
End of the free trial period, in ISO 8061 format. UTC timezone. Example, "
freeTrialEndTime":"2019-08-31T17:28:54.564Z" This time will be set the same as
initial subscription creation time if no free trial period is offered to the
partner.
Corresponds to the JSON property freeTrialEndTime
334 335 336 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 334 def free_trial_end_time @free_trial_end_time end |
#renewal_time ⇒ String
Output only. The time at which the subscription is expected to be renewed by
Google - a new charge will be incurred and the service entitlement will be
renewed. A non-immediate cancellation will take place at this time too, before
which, the service entitlement for the end user will remain valid. UTC
timezone in ISO 8061 format. For example: "2019-08-31T17:28:54.564Z"
Corresponds to the JSON property renewalTime
343 344 345 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 343 def renewal_time @renewal_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
350 351 352 353 354 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 350 def update!(**args) @cycle_end_time = args[:cycle_end_time] if args.key?(:cycle_end_time) @free_trial_end_time = args[:free_trial_end_time] if args.key?(:free_trial_end_time) @renewal_time = args[:renewal_time] if args.key?(:renewal_time) end |