Class: Google::Apis::PaymentsresellersubscriptionV1::FindEligiblePromotionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Request to find eligible promotions for the current user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FindEligiblePromotionsRequest

Returns a new instance of FindEligiblePromotionsRequest.



415
416
417
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. Specifies the filters for the promotion results. The syntax is defined in https://google.aip.dev/160 with the following caveats: 1. Only the following features are supported: - Logical operator AND - Comparison operator = (no wildcards *) - Traversal operator . - Has operator : ( no wildcards *) 2. Only the following fields are supported: - applicableProducts - regionCodes - youtubePayload.partnerEligibilityId - youtubePayload.postalCode 3. Unless explicitly mentioned above, other features are not supported. Example: applicableProducts:partners/partner1/ products/product1 AND regionCodes:US AND youtubePayload.postalCode=94043 AND youtubePayload.partnerEligibilityId=eligibility-id Corresponds to the JSON property filter

Returns:

  • (String)


398
399
400
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 398

def filter
  @filter
end

#page_sizeFixnum

Optional. The maximum number of promotions to return. The service may return fewer than this value. If unspecified, at most 50 promotions will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


405
406
407
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 405

def page_size
  @page_size
end

#page_tokenString

Optional. A page token, received from a previous FindEligiblePromotions call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to FindEligiblePromotions must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


413
414
415
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 413

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



420
421
422
423
424
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 420

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end