Class: Google::Apis::PaymentsresellersubscriptionV1::FindEligiblePromotionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Response containing the found promotions for the current user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FindEligiblePromotionsResponse

Returns a new instance of FindEligiblePromotionsResponse.



442
443
444
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


435
436
437
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 435

def next_page_token
  @next_page_token
end

#promotionsArray<Google::Apis::PaymentsresellersubscriptionV1::Promotion>

The promotions for the current user. Corresponds to the JSON property promotions



440
441
442
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 440

def promotions
  @promotions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



447
448
449
450
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 447

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @promotions = args[:promotions] if args.key?(:promotions)
end