Class: Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Details for a subscription line item with finite billing cycles.
Instance Attribute Summary collapse
-
#billing_cycle_count_limit ⇒ Fixnum
The number of a subscription line item billing cycles after which billing will stop automatically.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FiniteBillingCycleDetails
constructor
A new instance of FiniteBillingCycleDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FiniteBillingCycleDetails
Returns a new instance of FiniteBillingCycleDetails.
463 464 465 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_cycle_count_limit ⇒ Fixnum
The number of a subscription line item billing cycles after which billing will
stop automatically.
Corresponds to the JSON property billingCycleCountLimit
461 462 463 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 461 def billing_cycle_count_limit @billing_cycle_count_limit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
468 469 470 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 468 def update!(**args) @billing_cycle_count_limit = args[:billing_cycle_count_limit] if args.key?(:billing_cycle_count_limit) end |