Class: Google::Apis::PaymentsresellersubscriptionV1::GoogleHomePayload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Payload specific for Google Home products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleHomePayload

Returns a new instance of GoogleHomePayload.



544
545
546
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attached_to_google_structureBoolean Also known as: attached_to_google_structure?

Output only. This identifies whether the subscription is attached to a Google Home structure. Corresponds to the JSON property attachedToGoogleStructure

Returns:

  • (Boolean)


529
530
531
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 529

def attached_to_google_structure
  @attached_to_google_structure
end

#google_structure_idString

Optional. Structure identifier on Google side. Corresponds to the JSON property googleStructureId

Returns:

  • (String)


535
536
537
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 535

def google_structure_id
  @google_structure_id
end

#partner_structure_idString

Optional. This identifies the structure ID on partner side that the subscription should be applied to. Only required when the partner requires structure mapping. Corresponds to the JSON property partnerStructureId

Returns:

  • (String)


542
543
544
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 542

def partner_structure_id
  @partner_structure_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



549
550
551
552
553
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 549

def update!(**args)
  @attached_to_google_structure = args[:attached_to_google_structure] if args.key?(:attached_to_google_structure)
  @google_structure_id = args[:google_structure_id] if args.key?(:google_structure_id)
  @partner_structure_id = args[:partner_structure_id] if args.key?(:partner_structure_id)
end