Class: Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetails
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Details for a bundle product.
Instance Attribute Summary collapse
-
#bundle_elements ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetailsBundleElement>
The individual products that are included in the bundle.
-
#entitlement_mode ⇒ String
The entitlement mode of the bundle product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductBundleDetails
constructor
A new instance of ProductBundleDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductBundleDetails
Returns a new instance of ProductBundleDetails.
827 828 829 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bundle_elements ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetailsBundleElement>
The individual products that are included in the bundle.
Corresponds to the JSON property bundleElements
820 821 822 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 820 def bundle_elements @bundle_elements end |
#entitlement_mode ⇒ String
The entitlement mode of the bundle product.
Corresponds to the JSON property entitlementMode
825 826 827 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 825 def entitlement_mode @entitlement_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
832 833 834 835 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 832 def update!(**args) @bundle_elements = args[:bundle_elements] if args.key?(:bundle_elements) @entitlement_mode = args[:entitlement_mode] if args.key?(:entitlement_mode) end |