Class: Google::Apis::PaymentsresellersubscriptionV1::Promotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

A Promotion resource that defines a promotion for a subscription that can be resold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Promotion

Returns a new instance of Promotion.



970
971
972
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicable_productsArray<String>

Output only. The product ids this promotion can be applied to. Corresponds to the JSON property applicableProducts

Returns:

  • (Array<String>)


924
925
926
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 924

def applicable_products
  @applicable_products
end

#end_timeString

Optional. Specifies the end time (exclusive) of the period that the promotion is available in. If unset, the promotion is available indefinitely. Corresponds to the JSON property endTime

Returns:

  • (String)


930
931
932
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 930

def end_time
  @end_time
end

#free_trial_durationGoogle::Apis::PaymentsresellersubscriptionV1::Duration

Describes the length of a period of a time. Corresponds to the JSON property freeTrialDuration



935
936
937
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 935

def free_trial_duration
  @free_trial_duration
end

#introductory_pricing_detailsGoogle::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetails

The details of a introductory pricing promotion. Corresponds to the JSON property introductoryPricingDetails



940
941
942
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 940

def introductory_pricing_details
  @introductory_pricing_details
end

#nameString

Identifier. Response only. Resource name of the subscription promotion. It will have the format of "partners/partner_id/promotion/promotion_id" Corresponds to the JSON property name

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 946

def name
  @name
end

#promotion_typeString

Output only. Specifies the type of the promotion. Corresponds to the JSON property promotionType

Returns:

  • (String)


951
952
953
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 951

def promotion_type
  @promotion_type
end

#region_codesArray<String>

Output only. 2-letter ISO region code where the promotion is available in. Ex. "US" Please refer to: https://en.wikipedia.org/wiki/ISO_3166-1 Corresponds to the JSON property regionCodes

Returns:

  • (Array<String>)


957
958
959
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 957

def region_codes
  @region_codes
end

#start_timeString

Optional. Specifies the start time (inclusive) of the period that the promotion is available in. Corresponds to the JSON property startTime

Returns:

  • (String)


963
964
965
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 963

def start_time
  @start_time
end

#titlesArray<Google::Apis::PaymentsresellersubscriptionV1::GoogleTypeLocalizedText>

Output only. Localized human readable name of the promotion. Corresponds to the JSON property titles



968
969
970
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 968

def titles
  @titles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



975
976
977
978
979
980
981
982
983
984
985
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 975

def update!(**args)
  @applicable_products = args[:applicable_products] if args.key?(:applicable_products)
  @end_time = args[:end_time] if args.key?(:end_time)
  @free_trial_duration = args[:free_trial_duration] if args.key?(:free_trial_duration)
  @introductory_pricing_details = args[:introductory_pricing_details] if args.key?(:introductory_pricing_details)
  @name = args[:name] if args.key?(:name)
  @promotion_type = args[:promotion_type] if args.key?(:promotion_type)
  @region_codes = args[:region_codes] if args.key?(:region_codes)
  @start_time = args[:start_time] if args.key?(:start_time)
  @titles = args[:titles] if args.key?(:titles)
end