Class: Google::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetailsIntroductoryPricingSpec
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetailsIntroductoryPricingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
The duration of an introductory pricing promotion.
Instance Attribute Summary collapse
-
#discount_amount ⇒ Google::Apis::PaymentsresellersubscriptionV1::Amount
Describes the amount unit including the currency code.
-
#discount_ratio_micros ⇒ Fixnum
Output only.
-
#recurrence_count ⇒ Fixnum
Output only.
-
#region_code ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PromotionIntroductoryPricingDetailsIntroductoryPricingSpec
constructor
A new instance of PromotionIntroductoryPricingDetailsIntroductoryPricingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PromotionIntroductoryPricingDetailsIntroductoryPricingSpec
Returns a new instance of PromotionIntroductoryPricingDetailsIntroductoryPricingSpec.
1033 1034 1035 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discount_amount ⇒ Google::Apis::PaymentsresellersubscriptionV1::Amount
Describes the amount unit including the currency code.
Corresponds to the JSON property discountAmount
1014 1015 1016 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1014 def discount_amount @discount_amount end |
#discount_ratio_micros ⇒ Fixnum
Output only. The discount percentage in micros. For example, 50,000 represents
5%.
Corresponds to the JSON property discountRatioMicros
1020 1021 1022 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1020 def discount_ratio_micros @discount_ratio_micros end |
#recurrence_count ⇒ Fixnum
Output only. The duration of an introductory offer in billing cycles.
Corresponds to the JSON property recurrenceCount
1025 1026 1027 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1025 def recurrence_count @recurrence_count end |
#region_code ⇒ String
Output only. 2-letter ISO region code where the product is available in. Ex. "
US".
Corresponds to the JSON property regionCode
1031 1032 1033 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1031 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1038 1039 1040 1041 1042 1043 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1038 def update!(**args) @discount_amount = args[:discount_amount] if args.key?(:discount_amount) @discount_ratio_micros = args[:discount_ratio_micros] if args.key?(:discount_ratio_micros) @recurrence_count = args[:recurrence_count] if args.key?(:recurrence_count) @region_code = args[:region_code] if args.key?(:region_code) end |