Class: Google::Apis::PaymentsresellersubscriptionV1::ResumeSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::ResumeSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Request to resume a suspended subscription.
Instance Attribute Summary collapse
-
#cycle_options ⇒ Google::Apis::PaymentsresellersubscriptionV1::CycleOptions
The cycle options when starting and resuming a subscription.
-
#resume_mode ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResumeSubscriptionRequest
constructor
A new instance of ResumeSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResumeSubscriptionRequest
Returns a new instance of ResumeSubscriptionRequest.
1059 1060 1061 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cycle_options ⇒ Google::Apis::PaymentsresellersubscriptionV1::CycleOptions
The cycle options when starting and resuming a subscription.
Corresponds to the JSON property cycleOptions
1052 1053 1054 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1052 def @cycle_options end |
#resume_mode ⇒ String
Required. The mode to resume the subscription.
Corresponds to the JSON property resumeMode
1057 1058 1059 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1057 def resume_mode @resume_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1064 1065 1066 1067 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1064 def update!(**args) @cycle_options = args[:cycle_options] if args.key?(:cycle_options) @resume_mode = args[:resume_mode] if args.key?(:resume_mode) end |