Class: Google::Apis::PaymentsresellersubscriptionV1::ServicePeriod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

A description of what time period or moment in time the product or service is being delivered over.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServicePeriod

Returns a new instance of ServicePeriod.



1109
1110
1111
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. The end time of the service period. Time is exclusive. Corresponds to the JSON property endTime

Returns:

  • (String)


1102
1103
1104
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1102

def end_time
  @end_time
end

#start_timeString

Required. The start time of the service period. Time is inclusive. Corresponds to the JSON property startTime

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1107

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1114
1115
1116
1117
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1114

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end