Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Individual line item definition of a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionLineItem

Returns a new instance of SubscriptionLineItem.



1386
1387
1388
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountGoogle::Apis::PaymentsresellersubscriptionV1::Amount

Describes the amount unit including the currency code. Corresponds to the JSON property amount



1316
1317
1318
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1316

def amount
  @amount
end

#bundle_detailsGoogle::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemBundleDetails

The bundle details for a line item corresponding to a hard bundle. Corresponds to the JSON property bundleDetails



1321
1322
1323
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1321

def bundle_details
  @bundle_details
end

#descriptionString

Output only. Description of this line item. Corresponds to the JSON property description

Returns:

  • (String)


1326
1327
1328
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1326

def description
  @description
end

#finite_billing_cycle_detailsGoogle::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails

Details for a subscription line item with finite billing cycles. Corresponds to the JSON property finiteBillingCycleDetails



1331
1332
1333
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1331

def finite_billing_cycle_details
  @finite_billing_cycle_details
end

#line_item_free_trial_end_timeString

Output only. The free trial end time will be populated after the line item is successfully processed. End time of the line item free trial period, in ISO 8061 format. For example, "2019-08-31T17:28:54.564Z". It will be set the same as createTime if no free trial promotion is specified. Corresponds to the JSON property lineItemFreeTrialEndTime

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1339

def line_item_free_trial_end_time
  @line_item_free_trial_end_time
end

#line_item_indexFixnum

Output only. A unique index of the subscription line item. Corresponds to the JSON property lineItemIndex

Returns:

  • (Fixnum)


1344
1345
1346
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1344

def line_item_index
  @line_item_index
end

#line_item_promotion_specsArray<Google::Apis::PaymentsresellersubscriptionV1::SubscriptionPromotionSpec>

Optional. The promotions applied on the line item. It can be: - an introductory pricing promotion. - a free trial promotion. This feature is not enabled. If used, the request will be rejected. When used as input in Create or Provision API, specify its resource name only. Corresponds to the JSON property lineItemPromotionSpecs



1352
1353
1354
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1352

def line_item_promotion_specs
  @line_item_promotion_specs
end

#nameString

Identifier. Resource name of the line item. Format: partners/partner/ subscriptions/subscription/lineItems/lineItem Corresponds to the JSON property name

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1358

def name
  @name
end

#one_time_recurrence_detailsGoogle::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails

Details for a ONE_TIME recurrence line item. Corresponds to the JSON property oneTimeRecurrenceDetails



1363
1364
1365
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1363

def one_time_recurrence_details
  @one_time_recurrence_details
end

#productString

Required. Product resource name that identifies the product associated with this line item. The format is 'partners/partner_id/products/product_id'. Corresponds to the JSON property product

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1369

def product
  @product
end

#product_payloadGoogle::Apis::PaymentsresellersubscriptionV1::ProductPayload

Specifies product specific payload. Corresponds to the JSON property productPayload



1374
1375
1376
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1374

def product_payload
  @product_payload
end

#recurrence_typeString

Output only. The recurrence type of the line item. Corresponds to the JSON property recurrenceType

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1379

def recurrence_type
  @recurrence_type
end

#stateString

Output only. The state of the line item. Corresponds to the JSON property state

Returns:

  • (String)


1384
1385
1386
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1384

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1391

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @bundle_details = args[:bundle_details] if args.key?(:bundle_details)
  @description = args[:description] if args.key?(:description)
  @finite_billing_cycle_details = args[:finite_billing_cycle_details] if args.key?(:finite_billing_cycle_details)
  @line_item_free_trial_end_time = args[:line_item_free_trial_end_time] if args.key?(:line_item_free_trial_end_time)
  @line_item_index = args[:line_item_index] if args.key?(:line_item_index)
  @line_item_promotion_specs = args[:line_item_promotion_specs] if args.key?(:line_item_promotion_specs)
  @name = args[:name] if args.key?(:name)
  @one_time_recurrence_details = args[:one_time_recurrence_details] if args.key?(:one_time_recurrence_details)
  @product = args[:product] if args.key?(:product)
  @product_payload = args[:product_payload] if args.key?(:product_payload)
  @recurrence_type = args[:recurrence_type] if args.key?(:recurrence_type)
  @state = args[:state] if args.key?(:state)
end