Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemBundleDetailsBundleElementDetails
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemBundleDetailsBundleElementDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
The details for an element in the hard bundle.
Instance Attribute Summary collapse
-
#product ⇒ String
Output only.
-
#user_account_linked_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionLineItemBundleDetailsBundleElementDetails
constructor
A new instance of SubscriptionLineItemBundleDetailsBundleElementDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionLineItemBundleDetailsBundleElementDetails
Returns a new instance of SubscriptionLineItemBundleDetailsBundleElementDetails.
1441 1442 1443 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product ⇒ String
Output only. Product resource name that identifies the bundle element. The
format is 'partners/partner_id/products/product_id'.
Corresponds to the JSON property product
1434 1435 1436 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1434 def product @product end |
#user_account_linked_time ⇒ String
Output only. The time when this product is linked to an end user.
Corresponds to the JSON property userAccountLinkedTime
1439 1440 1441 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1439 def user_account_linked_time @user_account_linked_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1446 1447 1448 1449 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1446 def update!(**args) @product = args[:product] if args.key?(:product) @user_account_linked_time = args[:user_account_linked_time] if args.key?(:user_account_linked_time) end |