Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Details for a ONE_TIME recurrence line item.
Instance Attribute Summary collapse
-
#service_period ⇒ Google::Apis::PaymentsresellersubscriptionV1::ServicePeriod
A description of what time period or moment in time the product or service is being delivered over.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionLineItemOneTimeRecurrenceDetails
constructor
A new instance of SubscriptionLineItemOneTimeRecurrenceDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionLineItemOneTimeRecurrenceDetails
Returns a new instance of SubscriptionLineItemOneTimeRecurrenceDetails.
1463 1464 1465 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_period ⇒ Google::Apis::PaymentsresellersubscriptionV1::ServicePeriod
A description of what time period or moment in time the product or service is
being delivered over.
Corresponds to the JSON property servicePeriod
1461 1462 1463 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1461 def service_period @service_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1468 1469 1470 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1468 def update!(**args) @service_period = args[:service_period] if args.key?(:service_period) end |