Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionPromotionSpec
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::SubscriptionPromotionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Describes the spec for one promotion.
Instance Attribute Summary collapse
-
#free_trial_duration ⇒ Google::Apis::PaymentsresellersubscriptionV1::Duration
Describes the length of a period of a time.
-
#introductory_pricing_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetails
The details of a introductory pricing promotion.
-
#promotion ⇒ String
Required.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionPromotionSpec
constructor
A new instance of SubscriptionPromotionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionPromotionSpec
Returns a new instance of SubscriptionPromotionSpec.
1516 1517 1518 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#free_trial_duration ⇒ Google::Apis::PaymentsresellersubscriptionV1::Duration
Describes the length of a period of a time.
Corresponds to the JSON property freeTrialDuration
1498 1499 1500 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1498 def free_trial_duration @free_trial_duration end |
#introductory_pricing_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetails
The details of a introductory pricing promotion.
Corresponds to the JSON property introductoryPricingDetails
1503 1504 1505 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1503 def introductory_pricing_details @introductory_pricing_details end |
#promotion ⇒ String
Required. Promotion resource name that identifies a promotion. The format is '
partners/partner_id/promotions/promotion_id'.
Corresponds to the JSON property promotion
1509 1510 1511 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1509 def promotion @promotion end |
#type ⇒ String
Output only. The type of the promotion for the spec.
Corresponds to the JSON property type
1514 1515 1516 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1514 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1521 1522 1523 1524 1525 1526 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1521 def update!(**args) @free_trial_duration = args[:free_trial_duration] if args.key?(:free_trial_duration) @introductory_pricing_details = args[:introductory_pricing_details] if args.key?(:introductory_pricing_details) @promotion = args[:promotion] if args.key?(:promotion) @type = args[:type] if args.key?(:type) end |