Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionUpgradeDowngradeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Details about the previous subscription that this new subscription upgrades/ downgrades from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionUpgradeDowngradeDetails

Returns a new instance of SubscriptionUpgradeDowngradeDetails.



1548
1549
1550
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_cycle_specString

Required. Specifies the billing cycle spec for the new upgraded/downgraded subscription. Corresponds to the JSON property billingCycleSpec

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1538

def billing_cycle_spec
  @billing_cycle_spec
end

#previous_subscription_idString

Required. The previous subscription id to be replaced. The format can be one of the following: 1. subscription_id: the old subscription id under the same partner_id. 2. partners/partner_id/subscriptions/subscription_id`. A different partner_id is allowed. But they must be under the same partner group. Corresponds to the JSON propertypreviousSubscriptionId`

Returns:

  • (String)


1546
1547
1548
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1546

def previous_subscription_id
  @previous_subscription_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1553
1554
1555
1556
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1553

def update!(**args)
  @billing_cycle_spec = args[:billing_cycle_spec] if args.key?(:billing_cycle_spec)
  @previous_subscription_id = args[:previous_subscription_id] if args.key?(:previous_subscription_id)
end