Class: Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Partner request for entitling the previously provisioned subscription to an end user. The end user identity is inferred from the request OAuth context.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntitleSubscriptionRequest
constructor
A new instance of EntitleSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntitleSubscriptionRequest
Returns a new instance of EntitleSubscriptionRequest.
227 228 229 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#line_item_entitlement_details ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::EntitleSubscriptionRequestLineItemEntitlementDetails>
Optional. The line items to be entitled. If unspecified, all line items will
be entitled.
Corresponds to the JSON property lineItemEntitlementDetails
225 226 227 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 225 def line_item_entitlement_details @line_item_entitlement_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
232 233 234 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 232 def update!(**args) @line_item_entitlement_details = args[:line_item_entitlement_details] if args.key?(:line_item_entitlement_details) end |