Class: Google::Apis::PaymentsresellersubscriptionV1::GenerateUserSessionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Response that contains the details for generated user session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateUserSessionResponse

Returns a new instance of GenerateUserSessionResponse.



510
511
512
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_sessionGoogle::Apis::PaymentsresellersubscriptionV1::UserSession

Contains a short-lived token containing information required to interact with the Google Payments Reseller Platform via web endpoints. - Generate a user session token dynamically for an authenticated user. Do not share a token directly with a user in an unauthenticated context, such as SMS or email. - You can regenerate new session tokens repeatedly for the same generate request if necessary, regardless of whether previous tokens have expired. Multiple sessions will not result in duplicate fulfillments because the subscription ID guarantees uniqueness. For more integration details, see the Google Managed Signup documentation. Corresponds to the JSON property userSession



508
509
510
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 508

def user_session
  @user_session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



515
516
517
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 515

def update!(**args)
  @user_session = args[:user_session] if args.key?(:user_session)
end