Class: Google::Apis::PaymentsresellersubscriptionV1::Product
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::Product
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
A Product resource that defines a subscription service that can be resold.
Instance Attribute Summary collapse
-
#bundle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetails
Details for a bundle product.
-
#finite_billing_cycle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
Details for a subscription line item with finite billing cycles.
-
#name ⇒ String
Identifier.
-
#price_configs ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::ProductPriceConfig>
Output only.
-
#product_type ⇒ String
Output only.
-
#region_codes ⇒ Array<String>
Output only.
-
#subscription_billing_cycle_duration ⇒ Google::Apis::PaymentsresellersubscriptionV1::Duration
Describes the length of a period of a time.
-
#titles ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::GoogleTypeLocalizedText>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Product
constructor
A new instance of Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Product
Returns a new instance of Product.
807 808 809 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bundle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::ProductBundleDetails
Details for a bundle product.
Corresponds to the JSON property bundleDetails
768 769 770 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 768 def bundle_details @bundle_details end |
#finite_billing_cycle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
Details for a subscription line item with finite billing cycles.
Corresponds to the JSON property finiteBillingCycleDetails
773 774 775 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 773 def finite_billing_cycle_details @finite_billing_cycle_details end |
#name ⇒ String
Identifier. Response only. Resource name of the product. It will have the
format of "partners/partner_id/products/product_id"
Corresponds to the JSON property name
779 780 781 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 779 def name @name end |
#price_configs ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::ProductPriceConfig>
Output only. Price configs for the product in the available regions.
Corresponds to the JSON property priceConfigs
784 785 786 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 784 def price_configs @price_configs end |
#product_type ⇒ String
Output only. Specifies the type of the product.
Corresponds to the JSON property productType
789 790 791 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 789 def product_type @product_type end |
#region_codes ⇒ Array<String>
Output only. 2-letter ISO region code where the product is available in. Ex. "
US" Please refer to: https://en.wikipedia.org/wiki/ISO_3166-1
Corresponds to the JSON property regionCodes
795 796 797 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 795 def region_codes @region_codes end |
#subscription_billing_cycle_duration ⇒ Google::Apis::PaymentsresellersubscriptionV1::Duration
Describes the length of a period of a time.
Corresponds to the JSON property subscriptionBillingCycleDuration
800 801 802 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 800 def subscription_billing_cycle_duration @subscription_billing_cycle_duration end |
#titles ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::GoogleTypeLocalizedText>
Output only. Localized human readable name of the product.
Corresponds to the JSON property titles
805 806 807 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 805 def titles @titles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
812 813 814 815 816 817 818 819 820 821 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 812 def update!(**args) @bundle_details = args[:bundle_details] if args.key?(:bundle_details) @finite_billing_cycle_details = args[:finite_billing_cycle_details] if args.key?(:finite_billing_cycle_details) @name = args[:name] if args.key?(:name) @price_configs = args[:price_configs] if args.key?(:price_configs) @product_type = args[:product_type] if args.key?(:product_type) @region_codes = args[:region_codes] if args.key?(:region_codes) @subscription_billing_cycle_duration = args[:subscription_billing_cycle_duration] if args.key?(:subscription_billing_cycle_duration) @titles = args[:titles] if args.key?(:titles) end |