Class: Google::Apis::PaymentsresellersubscriptionV1::PromotionIntroductoryPricingDetailsIntroductoryPricingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

The duration of an introductory pricing promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PromotionIntroductoryPricingDetailsIntroductoryPricingSpec

Returns a new instance of PromotionIntroductoryPricingDetailsIntroductoryPricingSpec.



1032
1033
1034
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discount_amountGoogle::Apis::PaymentsresellersubscriptionV1::Amount

Describes the amount unit including the currency code. Corresponds to the JSON property discountAmount



1013
1014
1015
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1013

def discount_amount
  @discount_amount
end

#discount_ratio_microsFixnum

Output only. The discount percentage in micros. For example, 50,000 represents 5%. Corresponds to the JSON property discountRatioMicros

Returns:

  • (Fixnum)


1019
1020
1021
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1019

def discount_ratio_micros
  @discount_ratio_micros
end

#recurrence_countFixnum

Output only. The duration of an introductory offer in billing cycles. Corresponds to the JSON property recurrenceCount

Returns:

  • (Fixnum)


1024
1025
1026
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1024

def recurrence_count
  @recurrence_count
end

#region_codeString

Output only. 2-letter ISO region code where the product is available in. Ex. " US". Corresponds to the JSON property regionCode

Returns:

  • (String)


1030
1031
1032
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1030

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1037
1038
1039
1040
1041
1042
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1037

def update!(**args)
  @discount_amount = args[:discount_amount] if args.key?(:discount_amount)
  @discount_ratio_micros = args[:discount_ratio_micros] if args.key?(:discount_ratio_micros)
  @recurrence_count = args[:recurrence_count] if args.key?(:recurrence_count)
  @region_code = args[:region_code] if args.key?(:region_code)
end