Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItem
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Individual line item definition of a subscription.
Instance Attribute Summary collapse
-
#amount ⇒ Google::Apis::PaymentsresellersubscriptionV1::Amount
Describes the amount unit including the currency code.
-
#bundle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemBundleDetails
The bundle details for a line item corresponding to a hard bundle.
-
#description ⇒ String
Output only.
-
#finite_billing_cycle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
Details for a subscription line item with finite billing cycles.
-
#line_item_free_trial_end_time ⇒ String
Output only.
-
#line_item_index ⇒ Fixnum
Output only.
-
#line_item_promotion_specs ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::SubscriptionPromotionSpec>
Optional.
-
#name ⇒ String
Identifier.
-
#one_time_recurrence_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails
Details for a ONE_TIME recurrence line item.
-
#product ⇒ String
Required.
-
#product_payload ⇒ Google::Apis::PaymentsresellersubscriptionV1::ProductPayload
Specifies product specific payload.
-
#recurrence_type ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscriptionLineItem
constructor
A new instance of SubscriptionLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscriptionLineItem
Returns a new instance of SubscriptionLineItem.
1385 1386 1387 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount ⇒ Google::Apis::PaymentsresellersubscriptionV1::Amount
Describes the amount unit including the currency code.
Corresponds to the JSON property amount
1315 1316 1317 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1315 def amount @amount end |
#bundle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemBundleDetails
The bundle details for a line item corresponding to a hard bundle.
Corresponds to the JSON property bundleDetails
1320 1321 1322 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1320 def bundle_details @bundle_details end |
#description ⇒ String
Output only. Description of this line item.
Corresponds to the JSON property description
1325 1326 1327 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1325 def description @description end |
#finite_billing_cycle_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::FiniteBillingCycleDetails
Details for a subscription line item with finite billing cycles.
Corresponds to the JSON property finiteBillingCycleDetails
1330 1331 1332 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1330 def finite_billing_cycle_details @finite_billing_cycle_details end |
#line_item_free_trial_end_time ⇒ String
Output only. The free trial end time will be populated after the line item is
successfully processed. End time of the line item free trial period, in ISO
8061 format. For example, "2019-08-31T17:28:54.564Z". It will be set the same
as createTime if no free trial promotion is specified.
Corresponds to the JSON property lineItemFreeTrialEndTime
1338 1339 1340 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1338 def line_item_free_trial_end_time @line_item_free_trial_end_time end |
#line_item_index ⇒ Fixnum
Output only. A unique index of the subscription line item.
Corresponds to the JSON property lineItemIndex
1343 1344 1345 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1343 def line_item_index @line_item_index end |
#line_item_promotion_specs ⇒ Array<Google::Apis::PaymentsresellersubscriptionV1::SubscriptionPromotionSpec>
Optional. The promotions applied on the line item. It can be: - an
introductory pricing promotion. - a free trial promotion. This feature is not
enabled. If used, the request will be rejected. When used as input in Create
or Provision API, specify its resource name only.
Corresponds to the JSON property lineItemPromotionSpecs
1351 1352 1353 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1351 def line_item_promotion_specs @line_item_promotion_specs end |
#name ⇒ String
Identifier. Resource name of the line item. Format: partners/partner/
subscriptions/subscription/lineItems/lineItem
Corresponds to the JSON property name
1357 1358 1359 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1357 def name @name end |
#one_time_recurrence_details ⇒ Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails
Details for a ONE_TIME recurrence line item.
Corresponds to the JSON property oneTimeRecurrenceDetails
1362 1363 1364 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1362 def one_time_recurrence_details @one_time_recurrence_details end |
#product ⇒ String
Required. Product resource name that identifies the product associated with
this line item. The format is 'partners/partner_id/products/product_id'.
Corresponds to the JSON property product
1368 1369 1370 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1368 def product @product end |
#product_payload ⇒ Google::Apis::PaymentsresellersubscriptionV1::ProductPayload
Specifies product specific payload.
Corresponds to the JSON property productPayload
1373 1374 1375 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1373 def product_payload @product_payload end |
#recurrence_type ⇒ String
Output only. The recurrence type of the line item.
Corresponds to the JSON property recurrenceType
1378 1379 1380 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1378 def recurrence_type @recurrence_type end |
#state ⇒ String
Output only. The state of the line item.
Corresponds to the JSON property state
1383 1384 1385 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1383 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1390 def update!(**args) @amount = args[:amount] if args.key?(:amount) @bundle_details = args[:bundle_details] if args.key?(:bundle_details) @description = args[:description] if args.key?(:description) @finite_billing_cycle_details = args[:finite_billing_cycle_details] if args.key?(:finite_billing_cycle_details) @line_item_free_trial_end_time = args[:line_item_free_trial_end_time] if args.key?(:line_item_free_trial_end_time) @line_item_index = args[:line_item_index] if args.key?(:line_item_index) @line_item_promotion_specs = args[:line_item_promotion_specs] if args.key?(:line_item_promotion_specs) @name = args[:name] if args.key?(:name) @one_time_recurrence_details = args[:one_time_recurrence_details] if args.key?(:one_time_recurrence_details) @product = args[:product] if args.key?(:product) @product_payload = args[:product_payload] if args.key?(:product_payload) @recurrence_type = args[:recurrence_type] if args.key?(:recurrence_type) @state = args[:state] if args.key?(:state) end |