Class: Google::Apis::PaymentsresellersubscriptionV1::SubscriptionLineItemOneTimeRecurrenceDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Details for a ONE_TIME recurrence line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionLineItemOneTimeRecurrenceDetails

Returns a new instance of SubscriptionLineItemOneTimeRecurrenceDetails.



1462
1463
1464
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_periodGoogle::Apis::PaymentsresellersubscriptionV1::ServicePeriod

A description of what time period or moment in time the product or service is being delivered over. Corresponds to the JSON property servicePeriod



1460
1461
1462
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1460

def service_period
  @service_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1467
1468
1469
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1467

def update!(**args)
  @service_period = args[:service_period] if args.key?(:service_period)
end