Class: Google::Apis::PaymentsresellersubscriptionV1::SuspendSubscriptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Request to suspend a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuspendSubscriptionRequest

Returns a new instance of SuspendSubscriptionRequest.



1571
1572
1573
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suspend_modeString

Optional. The mode to suspend the subscription. It's required for partners to specify the suspend mode, whether suspend immediately and indefinitely, or cancel the subscription after grace_period_millis or auto_cancel_duration_millis if it's not resumed. Corresponds to the JSON property suspendMode

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1569

def suspend_mode
  @suspend_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1576
1577
1578
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1576

def update!(**args)
  @suspend_mode = args[:suspend_mode] if args.key?(:suspend_mode)
end