Class: Google::Apis::PaymentsresellersubscriptionV1::SuspendSubscriptionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Response that contains the suspended subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuspendSubscriptionResponse

Returns a new instance of SuspendSubscriptionResponse.



1595
1596
1597
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subscriptionGoogle::Apis::PaymentsresellersubscriptionV1::Subscription

Acts as a central billing entity between an external partner and Google. Google services use the subscription state to grant or revoke the user's service entitlement. Note: The subscription state might not perfectly align with the user's service entitlement. Some services might continue providing access until the current cycle ends, even if the subscription is immediately canceled. Consult the relevant contract or product policy for specific details. Corresponds to the JSON property subscription



1593
1594
1595
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1593

def subscription
  @subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1600
1601
1602
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1600

def update!(**args)
  @subscription = args[:subscription] if args.key?(:subscription)
end