Class: Google::Apis::PaymentsresellersubscriptionV1::UserSession
- Inherits:
-
Object
- Object
- Google::Apis::PaymentsresellersubscriptionV1::UserSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb
Overview
Contains a short-lived token containing information required to interact with
the Google Payments Reseller Platform via web endpoints. - Generate a user
session token dynamically for an authenticated user. Do not share a token
directly with a user in an unauthenticated context, such as SMS or email. -
You can regenerate new session tokens repeatedly for the same generate
request if necessary, regardless of whether previous tokens have expired.
Multiple sessions will not result in duplicate fulfillments because the
subscription ID guarantees uniqueness. For more integration details, see the
Google Managed Signup documentation.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
Output only.
-
#token ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserSession
constructor
A new instance of UserSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserSession
Returns a new instance of UserSession.
1668 1669 1670 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
Output only. The time at which the user session expires.
Corresponds to the JSON property expireTime
1659 1660 1661 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1659 def expire_time @expire_time end |
#token ⇒ String
Output only. The encrypted token of the user session, including the
information of the user's intent and request. This token should be provided
when redirecting the user to Google.
Corresponds to the JSON property token
1666 1667 1668 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1666 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1673 1674 1675 1676 |
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1673 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @token = args[:token] if args.key?(:token) end |