Class: Google::Apis::PaymentsresellersubscriptionV1::UserSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/paymentsresellersubscription_v1/classes.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb,
lib/google/apis/paymentsresellersubscription_v1/representations.rb

Overview

Contains a short-lived token containing information required to interact with the Google Payments Reseller Platform via web endpoints. - Generate a user session token dynamically for an authenticated user. Do not share a token directly with a user in an unauthenticated context, such as SMS or email. - You can regenerate new session tokens repeatedly for the same generate request if necessary, regardless of whether previous tokens have expired. Multiple sessions will not result in duplicate fulfillments because the subscription ID guarantees uniqueness. For more integration details, see the Google Managed Signup documentation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserSession

Returns a new instance of UserSession.



1667
1668
1669
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Output only. The time at which the user session expires. Corresponds to the JSON property expireTime

Returns:

  • (String)


1658
1659
1660
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1658

def expire_time
  @expire_time
end

#tokenString

Output only. The encrypted token of the user session, including the information of the user's intent and request. This token should be provided when redirecting the user to Google. Corresponds to the JSON property token

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1665

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1672
1673
1674
1675
# File 'lib/google/apis/paymentsresellersubscription_v1/classes.rb', line 1672

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @token = args[:token] if args.key?(:token)
end